<?php

namespace Drupal\bigin_crm;

use Drupal\bigin_crm\BiginAuthService;
use Drupal\bigin_crm\Rest\RestClient;
use Drupal\bigin_crm\BiginPipelinesService;
use Drupal\Core\Config\ConfigFactoryInterface;

/**
 * To add new entities to the contacts module.
 */
class BiginContactsService {

  /**
   * The auth Service.
   *
   * @var \Drupal\bigin_crm\BiginAuthService
   */
  protected $authService;

  /**
   * The rest client.
   *
   * @var \Drupal\bigin_crm\Rest\RestClient
   */
  protected $client;

  /**
   * The pipeline Service.
   *
   * @var \Drupal\bigin_crm\BiginPipelinesService
   */
  protected $pipelineService;

  /**
   * Drupal\Core\Config\ConfigFactory definition.
   *
   * @var \Drupal\Core\Config\ConfigFactory
   */
  protected $configFactory;

  /**
   * Constructs a new Service object.
   *
   * @param \Drupal\bigin_crm\BiginAuthService
   *   The auth Service.
   * @param \Drupal\bigin_crm\Rest\RestClient
   *   The rest client.
   * @param \Drupal\bigin_crm\BiginPipelinesService
   *   The pipeline Service.
   * @param \Drupal\Core\Config\ConfigFactoryInterface
   *   Config Factory service object.
   */

  public function __construct(
    BiginAuthService $authService,
    RestClient $client,
    BiginPipelinesService $pipelineService,
    ConfigFactoryInterface $configFactory,
  ) {
    $this->authService = $authService;
    $this->client = $client;
    $this->pipelineService = $pipelineService;
    $this->configFactory = $configFactory;
  }

  /**
   * Add new contact to Bigin crm.
   *
   * @param array
   * User data.
   *
   * @return string
   * Api rest response
   */
  public function create($user) {
    $config = $this->configFactory->get('bigin_crm.settings');
    // User data
    $body['data'][0] = [
      'Last_Name' => $user['name'],
      'First_Name' => '',
      'Email' => $user['email'],
      'Owner' => [
        'id' => $config->get('deal_owner')
      ]
    ];
    
    $url = $this->authService->url_api() . '/bigin/v1/Contacts';
    $response = $this->client->api_call($url, [], $body, 'POST');

    if (!empty($response->data) && $response->data[0]->code == 'SUCCESS') {
      // Add new deal to pipelines
      $res = $this->pipelineService->create_deal(
        $response->data[0]->details->id,
        $user['name'],
        $user['roles'],
      );
      \Drupal::logger('bigin')->info(t('A contact has been created in Bigin'));
      return $res;
    } else {
      \Drupal::logger('bigin')->error(t('Error: @message', [
        '@message' => $response->data[0]->message
      ]));
    }
  }

  /**
   * Get list users.
   *
   * @return array
   * list users
   */
  public function get_users() {
    $path = $this->authService->url_api() . '/bigin/v1/users';
    $params = [
      'type' => 'AllUsers',
    ];

    $response = $this->client->api_call($path, $params, []);
    return $response->users ?? [];
  }

}
